<?php declare(strict_types=1);

namespace EuKit\Base;

/**
 * Class SiteLayout
 * @package EuKit\Base
 */
class SiteLayout
{
    /**
     * @var SiteLayout
     */
    private static $instance;

    /**
     * @var int|null The maximum width the site's content area can take, in pixels.
     *               This should mimick what is defined in the site's CSS.
     */
    private $maxPageWidth;

    /**
     * @var string|null CSS length, or part of a calc() expression, describing the total horizontal padding & margin
     *                  taken up by a container in the grid. Examples: '10px', '2vw + 1em'
     *                  This should mimick what is defined in the site's CSS.
     */
    private $containerHorizontalPadding;

    /**
     * @var array From smallest to largest: [string screenSizeName => int minScreenWidth, ...]
     *            This should mimick what is defined in the site's CSS.
     */
    private $screenSizeBreakpoints = [];

    private function __construct()
    {
        // Default values.
        $this->maxPageWidth = null;
        $this->containerHorizontalPadding = null;
        $this->screenSizeBreakpoints = [
            'xs' => 0,
            'sm' => 768,
            'md' => 992,
            'lg' => 1200
        ];
    }

    public static function getMaxPageWidth(): ?int
    {
        return self::getInstance()->maxPageWidth;
    }

    public static function setMaxPageWidth(?int $width): void
    {
        self::getInstance()->maxPageWidth = $width;
    }

    public static function getContainerHorizontalPadding(): ?string
    {
        return self::getInstance()->containerHorizontalPadding;
    }

    public static function setContainerHorizontalPadding(?string $padding): void
    {
        self::getInstance()->containerHorizontalPadding = $padding;
    }

    public static function getScreenSizeBreakpoints(): array
    {
        return self::getInstance()->screenSizeBreakpoints;
    }

    public static function setScreenSizeBreakpoint(string $screenSizeName, int $minScreenWidth): void
    {
        self::getInstance()->screenSizeBreakpoints[$screenSizeName] = $minScreenWidth;
    }

    public static function setScreenSizeBreakpoints(array $breakpoints): void
    {
        self::getInstance()->screenSizeBreakpoints = [];
        foreach ($breakpoints as $screenSizeName => $minScreenWidth) {
            self::getInstance()::setScreenSizeBreakpoint($screenSizeName, $minScreenWidth);
        }
    }

    private static function getInstance(): SiteLayout
    {
        if( self::$instance === null ) {
            self::$instance = new self();
        }

        return self::$instance;
    }
}
