<?php declare(strict_types=1);

namespace EuKit\Base\ViewModels;

use EuKit\Base\Interfaces\ViewModel;
use EuKit\Base\Parts\Concept;
use Everyware\Concepts\ConceptPost;
use Everyware\Concepts\Concepts;
use Infomaker\Everyware\Support\GenericPropertyObject;

/**
 * Class RelatedConcept
 * @package EuKit\Base\ViewModels
 */
class RelatedConcept implements ViewModel
{
    /**
     * Contains the article to fetch data from
     *
     * @var GenericPropertyObject
     */
    protected $viewData;

    /**
     * ViewModel constructor.
     *
     * @param GenericPropertyObject $object
     */
    public function __construct(Concept $concept)
    {
        $this->viewData = new GenericPropertyObject();
        $this->viewData->fill($concept->getProperties());
        $this->viewData->fill([
            'related_links' => $concept->getRelatedLinks(),
            'avatar'        => $concept->getAvatar(),
            'meta_data'     => $concept->getMetadata(),
            'permalink'     => $this->getPermalink($concept),
        ]);

    }

    private function getPermalink(Concept $concept)
    {
        $db = Concepts::init();

        $conceptPost = $db->findByUuid($concept->get('uuid'));

        return $conceptPost instanceof ConceptPost ? $conceptPost->permalink() : '';

    }

    /**
     * Retrieve data to be used in the View
     *
     * @return array
     */
    public function getViewData(): array
    {
        return $this->viewData->toArray();
    }
}
